@@ -3,7 +3,9 @@ import asyncio, os
 import json
 import shutil
 import re
+import hashlib
 from pathlib import Path
+import aiofiles
 from .media_helper import InoMediaHelper
 
 class InoFileHelper:
@@ -476,4 +478,81 @@ class InoFileHelper:
             "success": True,
             "msg": f"📂 Validating files completed",
             "log_lines": log_lines
-        }
\ No newline at end of file
+        }
+
+    @staticmethod
+    async def save_string_as_file(string: str, save_path:str) -> dict:
+        """
+        Asynchronously saves the given string to the specified path using aiofiles.
+        Creates parent directories if they do not exist.
+
+        Args:
+            string: The text content to write.
+            save_path: Full path (str) to the file to be written.
+
+        Returns:
+            dict with keys: success (bool), msg (str), path (str), size (int, optional)
+        """
+        try:
+            path = Path(save_path)
+            if path.parent and not path.parent.exists():
+                path.parent.mkdir(parents=True, exist_ok=True)
+
+            async with aiofiles.open(path, mode="w", encoding="utf-8", newline="\n") as f:
+                await f.write(string)
+
+            size = path.stat().st_size if path.exists() else 0
+            return {
+                "success": True,
+                "msg": f"✅ Saved string to '{path}'",
+                "path": str(path),
+                "size": size,
+            }
+        except Exception as e:
+            return {
+                "success": False,
+                "msg": f"❌ Failed to save string to '{save_path}': {e}",
+            }
+
+    @staticmethod
+    async def get_file_hash_sha_256(file_path: Path) -> dict:
+        """
+        Asynchronously calculate the SHA-256 hash of the given file using aiofiles.
+
+        Args:
+            file_path: Path to the file to hash.
+
+        Returns:
+            dict with keys:
+              - success (bool)
+              - msg (str)
+              - sha (str, hex digest) when success=True
+        """
+        try:
+            path = Path(file_path)
+            if not path.exists():
+                return {"success": False, "msg": f"❌ Path not found: {path}"}
+            if not path.is_file():
+                return {"success": False, "msg": f"❌ Not a file: {path}"}
+
+            sha256 = hashlib.sha256()
+            # Use a reasonable chunk size to support large files
+            chunk_size = 1024 * 1024  # 1 MiB
+            async with aiofiles.open(path, "rb") as f:
+                while True:
+                    chunk = await f.read(chunk_size)
+                    if not chunk:
+                        break
+                    sha256.update(chunk)
+
+            digest = sha256.hexdigest()
+            return {
+                "success": True,
+                "msg": f"✅ SHA-256 computed for '{path.name}'",
+                "sha": digest,
+            }
+        except Exception as e:
+            return {
+                "success": False,
+                "msg": f"❌ Failed to compute SHA-256 for '{file_path}': {e}",
+            }
\ No newline at end of file
